@@ -6,6 +6,7 @@ use 5.010;
 use utf8;
 
 use Moose ();
+use MooseX::App::Exporter qw(option command_short_description command_long_description);
 use Moose::Exporter;
 
 Moose::Exporter->setup_import_methods(
@@ -14,8 +15,7 @@ Moose::Exporter->setup_import_methods(
 );
 
 sub init_meta {
-    shift;
-    my (%args) = @_;
+    my ($class,%args) = @_;
     
     my $meta = Moose->init_meta( %args );
     
@@ -23,35 +23,17 @@ sub init_meta {
         for             => $meta,
         class_metaroles => {
             class           => ['MooseX::App::Meta::Role::Class::Command'],
-            #attribute       => ['MooseX::Getopt::Meta::Attribute::Trait'],
-        },
-        role_metaroles => {
-            #attribute       => ['MooseX::Getopt::Meta::Attribute::Trait'],
         },
     );
     
     Moose::Util::MetaRole::apply_base_class_roles(
         for             => $args{for_class},
-        roles           => ['MooseX::App::Common'],
+        roles           => ['MooseX::App::Role::Common'],
     );
     
     return $meta;
 }
 
-sub command_short_description($) {
-    my ( $meta, $description ) = @_;
-    return $meta->command_short_description($description);
-}
-
-sub command_long_description($) {
-    my ( $meta, $description ) = @_;
-    return $meta->command_long_description($description);
-}
-
-sub option {
-    goto &MooseX::App::option;
-}
-
 1;
 
 __END__
