@@ -14,7 +14,7 @@ use Module::Pluggable::Object;
 
 has 'app_messageclass' => (
     is          => 'rw',
-    isa         => 'Str',
+    isa         => 'ClassName',
     lazy_build  => 1,
 );
 
@@ -30,6 +30,12 @@ has 'app_base' => (
     default     => sub { Path::Class::File->new($0)->basename },
 );
 
+has 'app_fuzzy' => (
+    is          => 'rw',
+    isa         => 'Bool',
+    default     => 1,
+);
+
 has 'app_commands' => (
     is          => 'rw',
     isa         => 'HashRef[Str]',
@@ -91,32 +97,62 @@ sub proto_options {
     );
 }
 
-sub command_matching {
+sub command_candidates {
     my ($self,$command) = @_;
     
+    my $lc_command = lc($command);
+    my $commands = $self->app_commands;
+    
+    my @candidates;
+    my $candidate_length = length($command);
+    
+    # Compare all commands to find matching candidates
+    foreach my $command_name (keys %$commands) {
+        if ($lc_command eq substr($command_name,0,$candidate_length)) {
+            push(@candidates,$command_name);
+        }
+    }
+    return (sort @candidates);
+}
+
+sub command_get {
+    my ($self,$command) = @_;
+    
+    my $lc_command = lc($command);
     my $commands = $self->app_commands;
     
     # Exact match
-    if (defined $commands->{$command}) {
-        return $command;
-    # Fuzzy match
+    if (defined $commands->{$lc_command}) {
+        return $lc_command;
     } else {
-        my @candidates;
-        my $candidate_length = length($command);
-        my $lc_command = lc($command);
+        my @candidates =  $self->command_candidates($command);
         
-        # Compare all commands to find matching candidates
-        foreach my $command_name (keys %$commands) {
-            my $lc_command_name = lc($command_name);
-            if ($lc_command eq $lc_command_name) {
-                return $command_name;
+        given (scalar @candidates) {
+            when (0) {
+                return $self->command_message(
+                    header          => "Unknown command '$command'",
+                    type            => "error",
+                );
             }
-            if ($lc_command eq substr($lc_command_name,0,$candidate_length)) {
-                push(@candidates,$command_name);
+            when (1) {
+                if ($self->app_fuzzy) {
+                    return $candidates[0];
+                } else {
+                    return $self->command_message(
+                        header          => "Unknown command '$command'",
+                        type            => "error",
+                        body            => "Did you mean '".$candidates[0]."'?",
+                    );
+                }
+            }
+            default {
+                return $self->command_message(
+                    header          => "Ambiguous command '$command'",
+                    type            => "error",
+                    body            => "Which command did you mean?\n".MooseX::App::Utils::format_list(map { [ $_ ] } sort @candidates),
+                );
             }
-            
         }
-        return (sort @candidates);
     }
 }
 
@@ -156,7 +192,8 @@ sub command_usage_attributes_raw {
         push(@attributes,[$attribute_name,$attribute_description]);
     }
     
-    return sort { $a->[0] cmp $b->[0] } @attributes;
+    @attributes = sort { $a->[0] cmp $b->[0] } @attributes;
+    return @attributes;
 }
 
 sub command_usage_attribute_detail {
@@ -496,9 +533,9 @@ Returns a message containing the basic usage documentation
 
 Returns a hashref of command name and command class.
 
-=head2 command_matching
+=head2 command_get
 
- my @commands = $meta->command_matching($user_command_input);
+ my @commands = $meta->command_get($user_command_input);
 
 Returns a list of command names matching the user input
 
