@@ -1,7 +1,9 @@
 package Test02;
 
 use Moose;
-use MooseX::App qw(BashCompletion ConfigHome Color);
+use MooseX::App qw(BashCompletion ConfigHome Color Version Env Similar);
+
+our $VERSION = 1.01;
 
 app_namespace "Test02::Command";
 
